@@ -1,6 +1,6 @@
 from __future__ import unicode_literals
 
-from catsnap import Config
+from catsnap import Client
 
 class Document():
     _stored_table = None
@@ -8,9 +8,5 @@ class Document():
 
     def _table(self):
         self._stored_table = self._stored_table \
-                or Config().table(self._table_name)
+                or Client().table(self._table_name)
         return self._stored_table
-
-    @classmethod
-    def create(cls):
-        Config().create_table(cls._table_name)
